summaryrefslogtreecommitdiffstats
path: root/sys/kern/subr_smp.c
diff options
context:
space:
mode:
Diffstat (limited to 'sys/kern/subr_smp.c')
-rw-r--r--sys/kern/subr_smp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sys/kern/subr_smp.c b/sys/kern/subr_smp.c
index 7965b78..908d587 100644
--- a/sys/kern/subr_smp.c
+++ b/sys/kern/subr_smp.c
@@ -123,7 +123,7 @@ forward_signal(struct thread *td)
int id;
/*
* signotify() has already set KEF_ASTPENDING and PS_NEEDSIGCHECK on
* this process, so all we need to do is poke it if it is currently
* executing so that it executes ast().
*/
@@ -169,7 +169,7 @@ forward_roundrobin(void)
id = pc->pc_cpumask;
if (id != PCPU_GET(cpumask) && (id & stopped_cpus) == 0 &&
td != pc->pc_idlethread) {
- td->td_kse->ke_flags |= KEF_NEEDRESCHED;
+ td->td_flags |= TDF_NEEDRESCHED;
map |= id;
}
}
@@ -123,7 +123,7 @@ forward_signal(struct thread *td)
int id;
/*
- * signotify() has already set KEF_ASTPENDING and PS_NEEDSIGCHECK on
+ * signotify() has already set TDF_ASTPENDING and PS_NEEDSIGCHECK on
* this process, so all we need to do is poke it if it is currently
* executing so that it executes ast().
OpenPOWER on IntegriCloud